@@ -1,11 +1,10 @@
 package Pod::Weaver::Plugin::EnsurePod5;
 # ABSTRACT: ensure that the Pod5 translator has been run on this document
-$Pod::Weaver::Plugin::EnsurePod5::VERSION = '4.009';
+$Pod::Weaver::Plugin::EnsurePod5::VERSION = '4.010';
 use Moose;
 with 'Pod::Weaver::Role::Preparer';
 
 use namespace::autoclean;
-use Moose::Autobox;
 
 use Pod::Elemental::Transformer::Pod5;
 
@@ -21,8 +20,9 @@ sub _strip_nonpod {
   my ($self, $node) = @_;
 
   # XXX: This is really stupid. -- rjbs, 2009-10-24
-  $node->children->keys->reverse->each_value(sub {
-    my ($i, $para) = ($_, $node->children->[$_]);
+
+  foreach my $i (reverse 0 .. $#{ $node->children }) {
+    my $para = $node->children->[$i];
 
     if ($para->isa('Pod::Elemental::Element::Pod5::Nonpod')) {
       if ($para->content !~ /\S/) {
@@ -33,7 +33,7 @@ sub _strip_nonpod {
     } elsif ($para->does('Pod::Elemental::Node')) {
       $self->_strip_nonpod($para);
     }
-  });
+  }
 }
 
 sub prepare_input {
@@ -62,7 +62,7 @@ Pod::Weaver::Plugin::EnsurePod5 - ensure that the Pod5 translator has been run o
 
 =head1 VERSION
 
-version 4.009
+version 4.010
 
 =head1 OVERVIEW
 
