@@ -1,11 +1,9 @@
 package Pod::Weaver::Section::Authors;
 # ABSTRACT: a section listing authors
-$Pod::Weaver::Section::Authors::VERSION = '4.009';
+$Pod::Weaver::Section::Authors::VERSION = '4.010';
 use Moose;
 with 'Pod::Weaver::Role::Section';
 
-use Moose::Autobox;
-
 use Pod::Elemental::Element::Nested;
 use Pod::Elemental::Element::Pod5::Verbatim;
 
@@ -27,38 +25,37 @@ sub weave_section {
 
   return unless $input->{authors};
 
-  my $multiple_authors = $input->{authors}->length > 1;
+  my $multiple_authors = @{ $input->{authors} } > 1;
 
   my $name = $multiple_authors ? 'AUTHORS' : 'AUTHOR';
-  my $authors = $input->{authors}->map(sub {
+  my $authors = [ map {
     Pod::Elemental::Element::Pod5::Ordinary->new({
       content => $_,
     }),
-  });
+  } @{ $input->{authors} } ];
 
   $authors = [
     Pod::Elemental::Element::Pod5::Command->new({
       command => 'over', content => '4',
     }),
-    $authors->map(sub {
+    ( map {
       Pod::Elemental::Element::Pod5::Command->new({
         command => 'item', content => '*',
       }),
       $_,
-    })->flatten,
+    } @$authors ),
     Pod::Elemental::Element::Pod5::Command->new({
       command => 'back', content => '',
     }),
   ] if $multiple_authors;
 
-  $document->children->push(
+  push @{$document->children },
     Pod::Elemental::Element::Nested->new({
       type     => 'command',
       command  => 'head1',
       content  => $name,
       children => $authors,
-    }),
-  );
+    });
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -76,7 +73,7 @@ Pod::Weaver::Section::Authors - a section listing authors
 
 =head1 VERSION
 
-version 4.009
+version 4.010
 
 =head1 OVERVIEW
 
